@@ -35,7 +35,12 @@ class GeneratorDataStorage(GeneratorDataStorageBase):
                 impl = '''
                 template<>const {type}* DataStorage::get(const std::string& name) const
                 {{
-                    return _loaded ? &{name}.at(name) : &const_cast<DataStorage*>(this)->{name}[name];
+                    if(_loaded)
+                    {{
+                        auto iter = {name}.find(name);
+                        return iter != {name}.end() ? &iter->second : nullptr;
+                    }}
+                    return &const_cast<DataStorage*>(this)->{name}[name];
                 }}
                 '''
                 name = get_data_list_name(get_data_name(class_.name))
@@ -46,14 +51,11 @@ class GeneratorDataStorage(GeneratorDataStorageBase):
         return '''Json::Value json;
         Json::Reader reader;
         reader.parse(content, json);
-        DeserializerJson deserializer(json);
-        const_cast<DataStorage*>(this)->deserialize_json(deserializer);
+        const_cast<DataStorage*>(this)->deserialize_json(json);
         const_cast<DataStorage*>(this)->_loaded = true;'''
 
     def get_initialize_function_xml_body(self):
         return '''pugi::xml_document doc;
         doc.load(content.c_str());
-        pugi::xml_node node = doc.root().first_child();
-        DeserializerXml deserializer(node);
-        const_cast<DataStorage*>(this)->deserialize_xml(deserializer);
+        const_cast<DataStorage*>(this)->deserialize_xml(doc.root().first_child());
         const_cast<DataStorage*>(this)->_loaded = doc.root() != nullptr;'''
